import _plotly_utils.basevalidators


class ReversescaleValidator(_plotly_utils.basevalidators.BooleanValidator):

    def __init__(
        self,
        plotly_name='reversescale',
        parent_name='bar.marker.line',
        **kwargs
    ):
        super(ReversescaleValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type='calc',
            role='style',
            **kwargs
        )



import _plotly_utils.basevalidators


class RValidator(_plotly_utils.basevalidators.NumberValidator):

    def __init__(
        self, plotly_name='r', parent_name='layout.slider.pad', **kwargs
    ):
        super(RValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type='arraydraw',
            role='style',
            **kwargs
        )



import _plotly_utils.basevalidators


class SceneValidator(_plotly_utils.basevalidators.SubplotidValidator):

    def __init__(self, plotly_name='scene', parent_name='cone', **kwargs):
        super(SceneValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            dflt='scene',
            edit_type='calc+clearAxisTypes',
            role='info',
            **kwargs
        )
